from .awk import Awk
from .cat import Cat
from .compile import Compile
from .echo import Echo
from .md5sum import MD5Sum
from .sleep import Sleep
from .tar import Tar
from .untar import Untar
from .hello import HelloWorkflow

from .uncompressarchive import UncompressArchive
